@@ -640,6 +640,8 @@ ggit_repository_lookup_reference (GgitRepository  *repository,
  * @repository: a #GgitRepository.
  * @name: the name for the new #GgitRef.
  * @oid: the #GgitOId pointed to by the reference.
+ * @signature: a #GgitSignature that will used to populate the reflog entry.
+ * @log_message: The one line long message to be appended to the reflog.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Creates a new object id reference.
@@ -653,6 +655,8 @@ GgitRef *
 ggit_repository_create_reference (GgitRepository  *repository,
                                   const gchar     *name,
                                   GgitOId         *oid,
+                                  GgitSignature   *signature,
+                                  const gchar     *log_message,
                                   GError         **error)
 {
 	GgitRef *ref = NULL;
@@ -662,9 +666,13 @@ ggit_repository_create_reference (GgitRepository  *repository,
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (oid != NULL, NULL);
+	g_return_val_if_fail (GGIT_IS_SIGNATURE (signature), NULL);
+	g_return_val_if_fail (log_message != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	ret = git_reference_create (&reference, _ggit_native_get (repository),
-	                            name, _ggit_oid_get_oid (oid), FALSE);
+	                            name, _ggit_oid_get_oid (oid), FALSE,
+	                            _ggit_native_get (signature), log_message);
 
 	if (ret == GIT_OK)
 	{
@@ -683,6 +691,8 @@ ggit_repository_create_reference (GgitRepository  *repository,
  * @repository: a #GgitRepository.
  * @name: the name for the new #GgitRef.
  * @target: the full name to the reference.
+ * @signature: a #GgitSignature that will used to populate the reflog entry.
+ * @log_message: The one line long message to be appended to the reflog.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Creates a new symbolic reference.
@@ -696,6 +706,8 @@ GgitRef *
 ggit_repository_create_symbolic_reference (GgitRepository  *repository,
                                            const gchar     *name,
                                            const gchar     *target,
+                                           GgitSignature   *signature,
+                                           const gchar     *log_message,
                                            GError         **error)
 {
 	GgitRef *ref = NULL;
@@ -705,9 +717,13 @@ ggit_repository_create_symbolic_reference (GgitRepository  *repository,
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (target != NULL, NULL);
+	g_return_val_if_fail (GGIT_IS_SIGNATURE (signature), NULL);
+	g_return_val_if_fail (log_message != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	ret = git_reference_symbolic_create (&reference, _ggit_native_get (repository),
-	                                     name, target, FALSE);
+	                                     name, target, FALSE,
+	                                     _ggit_native_get (signature), log_message);
 
 	if (ret == GIT_OK)
 	{
@@ -774,10 +790,10 @@ GFile *
 ggit_repository_discover (GFile   *location,
                           GError **error)
 {
-	gchar found_path[GIT_PATH_MAX];
-	GFile *rep = NULL;
+	git_buf buf;
 	gchar *path;
 	gint ret;
+	GFile *rep = NULL;
 
 	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
@@ -786,8 +802,7 @@ ggit_repository_discover (GFile   *location,
 
 	g_return_val_if_fail (path != NULL, NULL);
 
-	ret = git_repository_discover (found_path,
-	                               sizeof (found_path),
+	ret = git_repository_discover (&buf,
 	                               path,
 	                               0,
 	                               "");
@@ -796,7 +811,8 @@ ggit_repository_discover (GFile   *location,
 
 	if (ret == GIT_OK)
 	{
-		rep = g_file_new_for_path (found_path);
+		rep = g_file_new_for_path (buf.ptr);
+		git_buf_free (&buf);
 	}
 	else
 	{
@@ -1356,6 +1372,8 @@ ggit_repository_list_tags (GgitRepository  *repository,
  * @branch_name: the name of the branch.
  * @target: a #GgitObject.
  * @flags: a #GgitCreateFlags.
+ * @signature: a #GgitSignature that will used to populate the reflog entry.
+ * @log_message: The one line long message to be appended to the reflog.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Creates a new branch pointing at a target commit.
@@ -1368,6 +1386,8 @@ ggit_repository_create_branch (GgitRepository   *repository,
                                const gchar      *branch_name,
                                GgitObject       *target,
                                GgitCreateFlags   flags,
+                               GgitSignature    *signature,
+                               const gchar      *log_message,
                                GError          **error)
 {
 	gboolean force;
@@ -1377,6 +1397,8 @@ ggit_repository_create_branch (GgitRepository   *repository,
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), FALSE);
 	g_return_val_if_fail (branch_name != NULL, FALSE);
 	g_return_val_if_fail (GGIT_IS_OBJECT (target), FALSE);
+	g_return_val_if_fail (GGIT_IS_SIGNATURE (signature), FALSE);
+	g_return_val_if_fail (log_message != NULL, FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
 	force = flags & GGIT_CREATE_FORCE;
@@ -1385,7 +1407,9 @@ ggit_repository_create_branch (GgitRepository   *repository,
 	                         _ggit_native_get (repository),
 	                         branch_name,
 	                         _ggit_native_get (target),
-	                         force ? 1 : 0);
+	                         force ? 1 : 0,
+	                         _ggit_native_get (signature),
+	                         log_message);
 
 	if (ret != GIT_OK)
 	{
@@ -1692,6 +1716,8 @@ ggit_repository_submodule_foreach (GgitRepository        *repository,
  * @repository: a #GgitRepository.
  * @target: the target #GgitObject which is a commit or a tag.
  * @reset_type: the #GgitResetType to perform.
+ * @signature: a #GgitSignature that will used to populate the reflog entry.
+ * @log_message: The one line long message to be appended to the reflog.
  * @error: a #GError for error reporting, or %NULL.
  *
  * Performs a reset of type @reset_type on @repository to @target,
@@ -1701,17 +1727,23 @@ void
 ggit_repository_reset (GgitRepository  *repository,
                        GgitObject      *target,
                        GgitResetType    reset_type,
+                       GgitSignature   *signature,
+                       const gchar     *log_message,
                        GError         **error)
 {
 	gint ret;
 
 	g_return_if_fail (GGIT_IS_REPOSITORY (repository));
 	g_return_if_fail (GGIT_IS_OBJECT (target));
+	g_return_val_if_fail (GGIT_IS_SIGNATURE (signature), FALSE);
+	g_return_val_if_fail (log_message != NULL, FALSE);
 	g_return_if_fail (error == NULL || *error == NULL);
 
 	ret = git_reset (_ggit_native_get (repository),
 	                 _ggit_native_get (target),
-	                 (git_reset_t)reset_type);
+	                 (git_reset_t)reset_type,
+	                 _ggit_native_get (signature),
+	                 log_message);
 
 	if (ret != GIT_OK)
 	{
@@ -2107,7 +2139,7 @@ ggit_repository_create_commit (GgitRepository  *repository,
 }
 
 /**
- * ggit_repository_create_commit_from_oids:
+ * ggit_repository_create_commit_from_ids:
  * @repository: a #GgitRepository.
  * @update_ref: (allow-none): name of the reference to update.
  * @author: author signature.
@@ -2131,19 +2163,19 @@ ggit_repository_create_commit (GgitRepository  *repository,
  *
  */
 GgitOId *
-ggit_repository_create_commit_from_oids (GgitRepository  *repository,
-                                         const gchar     *update_ref,
-                                         GgitSignature   *author,
-                                         GgitSignature   *committer,
-                                         const gchar     *message_encoding,
-                                         const gchar     *message,
-                                         GgitOId         *tree,
-                                         GgitOId        **parents,
-                                         gint             parent_count,
-                                         GError         **error)
+ggit_repository_create_commit_from_ids (GgitRepository  *repository,
+                                        const gchar     *update_ref,
+                                        GgitSignature   *author,
+                                        GgitSignature   *committer,
+                                        const gchar     *message_encoding,
+                                        const gchar     *message,
+                                        GgitOId         *tree,
+                                        GgitOId        **parents,
+                                        gint             parent_count,
+                                        GError         **error)
 {
 	gint ret;
-	git_oid oid;
+	git_oid id;
 	git_oid **parents_native;
 	gint i;
 
@@ -2154,16 +2186,16 @@ ggit_repository_create_commit_from_oids (GgitRepository  *repository,
 		parents_native[i] = (git_oid *)_ggit_oid_get_oid (parents[i]);
 	}
 
-	ret = git_commit_create_from_oids (&oid,
-	                                   _ggit_native_get (repository),
-	                                   update_ref,
-	                                   _ggit_native_get (author),
-	                                   _ggit_native_get (committer),
-	                                   message_encoding,
-	                                   message,
-	                                   _ggit_oid_get_oid (tree),
-	                                   parent_count,
-	                                   (git_oid const **)parents_native);
+	ret = git_commit_create_from_ids (&id,
+	                                  _ggit_native_get (repository),
+	                                  update_ref,
+	                                  _ggit_native_get (author),
+	                                  _ggit_native_get (committer),
+	                                  message_encoding,
+	                                  message,
+	                                  _ggit_oid_get_oid (tree),
+	                                  parent_count,
+	                                  (git_oid const **)parents_native);
 
 	g_free (parents_native);
 
@@ -2173,7 +2205,7 @@ ggit_repository_create_commit_from_oids (GgitRepository  *repository,
 		return NULL;
 	}
 
-	return _ggit_oid_wrap (&oid);
+	return _ggit_oid_wrap (&id);
 }
 
 /**
