@@ -97,12 +97,16 @@ GgitRef            *ggit_repository_lookup_reference  (GgitRepository        *re
 GgitRef            *ggit_repository_create_reference  (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GgitOId               *oid,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitRef            *ggit_repository_create_symbolic_reference
                                                       (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        const gchar           *target,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitBlobOutputStream *
@@ -136,7 +140,7 @@ GgitOId            *ggit_repository_create_commit     (GgitRepository        *re
                                                        gint                   parent_count,
                                                        GError               **error);
 
-GgitOId            *ggit_repository_create_commit_from_oids (
+GgitOId            *ggit_repository_create_commit_from_ids (
                                                        GgitRepository        *repository,
                                                        const gchar           *update_ref,
                                                        GgitSignature         *author,
@@ -196,6 +200,8 @@ GgitBranch         *ggit_repository_create_branch     (GgitRepository        *re
                                                        const gchar           *branch_name,
                                                        GgitObject            *target,
                                                        GgitCreateFlags        flags,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *log_message,
                                                        GError               **error);
 
 GgitBranchEnumerator *ggit_repository_enumerate_branches (GgitRepository        *repository,
@@ -277,6 +283,8 @@ gboolean            ggit_repository_submodule_foreach  (GgitRepository
 void                ggit_repository_reset              (GgitRepository          *repository,
                                                         GgitObject              *target,
                                                         GgitResetType            reset_type,
+                                                        GgitSignature           *signature,
+                                                        const gchar             *log_message,
                                                         GError                 **error);
 
 GgitObject         *ggit_repository_revparse          (GgitRepository        *repository,
@@ -305,6 +313,17 @@ void                ggit_repository_get_ahead_behind  (GgitRepository        *re
                                                        gsize                 *behind,
                                                        GError               **error);
 
+GgitBlame          *ggit_repository_blame_file        (GgitRepository        *repository,
+                                                       GFile                 *file,
+                                                       GgitBlameOptions      *blame_options,
+                                                       GError               **error);
+
+const gchar        *ggit_repository_get_attribute     (GgitRepository           *repository,
+                                                       const gchar              *path,
+                                                       const gchar              *name,
+                                                       GgitAttributeCheckFlags   flags,
+                                                       GError                  **error);
+
 G_END_DECLS
 
 #endif /* __GGIT_REPOSITORY_H__ */
